@@ -3,8 +3,11 @@ import warnings
 
 from skrt.better_viewer import BetterViewer
 from skrt.better_viewer.options import set_viewer_options
+from skrt.core import Defaults
 from skrt.image import Image
 from skrt.dose import Dose
+from skrt.registration import Registration
+from skrt.simulation import SyntheticImage
 from skrt.structures import ROI, StructureSet
 from skrt.patient import Patient, Study
 
